/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2013-02-12
 * Description : Table view column helpers
 *
 * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#pragma once

// Local includes

#include "tableview_column_audiovideo.h"
#include "tableview_column_digikam.h"
#include "tableview_column_file.h"
#include "tableview_column_geo.h"
#include "tableview_column_item.h"
#include "tableview_column_photo.h"
#include "tableview_column_thumbnail.h"
